# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccessStrategyArgs', 'AccessStrategy']

@pulumi.input_type
class AccessStrategyArgs:
    def __init__(__self__, *,
                 default_addr_pool_type: pulumi.Input[str],
                 default_addr_pools: pulumi.Input[Sequence[pulumi.Input['AccessStrategyDefaultAddrPoolArgs']]],
                 default_min_available_addr_num: pulumi.Input[int],
                 instance_id: pulumi.Input[str],
                 strategy_mode: pulumi.Input[str],
                 strategy_name: pulumi.Input[str],
                 access_mode: Optional[pulumi.Input[str]] = None,
                 default_latency_optimization: Optional[pulumi.Input[str]] = None,
                 default_lba_strategy: Optional[pulumi.Input[str]] = None,
                 default_max_return_addr_num: Optional[pulumi.Input[int]] = None,
                 failover_addr_pool_type: Optional[pulumi.Input[str]] = None,
                 failover_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyFailoverAddrPoolArgs']]]] = None,
                 failover_latency_optimization: Optional[pulumi.Input[str]] = None,
                 failover_lba_strategy: Optional[pulumi.Input[str]] = None,
                 failover_max_return_addr_num: Optional[pulumi.Input[int]] = None,
                 failover_min_available_addr_num: Optional[pulumi.Input[int]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 lines: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyLineArgs']]]] = None):
        """
        The set of arguments for constructing a AccessStrategy resource.
        :param pulumi.Input[str] default_addr_pool_type: The type of the primary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        :param pulumi.Input[Sequence[pulumi.Input['AccessStrategyDefaultAddrPoolArgs']]] default_addr_pools: List of primary address pool collections. See `default_addr_pools` below for details.
        :param pulumi.Input[int] default_min_available_addr_num: The minimum number of available addresses for the primary address pool set.
        :param pulumi.Input[str] instance_id: The Id of the associated instance.
        :param pulumi.Input[str] strategy_mode: The type of the access policy. Valid values: `GEO` or `LATENCY`. `GEO`: based on geographic location. `LATENCY`: Based on delay.
        :param pulumi.Input[str] strategy_name: The name of the access policy.
        :param pulumi.Input[str] access_mode: The primary/secondary switchover policy for address pool groups. Valid values: `AUTO`, `DEFAULT`, `FAILOVER`.
        :param pulumi.Input[str] default_latency_optimization: Specifies whether to enable scheduling optimization for latency resolution for the primary address pool group. Valid values: `OPEN`, `CLOSE`.
        :param pulumi.Input[str] default_lba_strategy: The load balancing policy of the primary address pool group. Valid values: `ALL_RR`, `RATIO`. **NOTE:** The `default_lba_strategy` is required under the condition that `strategy_mode` is `GEO`.
        :param pulumi.Input[int] default_max_return_addr_num: The maximum number of addresses returned by the primary address pool set. **NOTE:** The `default_max_return_addr_num` is required under the condition that `strategy_mode` is `LATENCY`.
        :param pulumi.Input[str] failover_addr_pool_type: The type of the secondary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        :param pulumi.Input[Sequence[pulumi.Input['AccessStrategyFailoverAddrPoolArgs']]] failover_addr_pools: List of backup address pool sets. See `failover_addr_pools` below for details.
        :param pulumi.Input[str] failover_latency_optimization: Specifies whether to enable scheduling optimization for latency resolution for the secondary address pool group. Valid values: `OPEN`, `CLOSE`.
        :param pulumi.Input[str] failover_lba_strategy: The load balancing policy of the secondary address pool group. Valid values: `ALL_RR`, `RATIO`.
        :param pulumi.Input[int] failover_max_return_addr_num: The maximum number of returned addresses in the standby address pool.
        :param pulumi.Input[int] failover_min_available_addr_num: The minimum number of available addresses in the standby address pool.
        :param pulumi.Input[str] lang: The lang.
        :param pulumi.Input[Sequence[pulumi.Input['AccessStrategyLineArgs']]] lines: The source regions. See `lines` below for details. **NOTE:** The `lines` is required under the condition that `strategy_mode` is `GEO`.
        """
        pulumi.set(__self__, "default_addr_pool_type", default_addr_pool_type)
        pulumi.set(__self__, "default_addr_pools", default_addr_pools)
        pulumi.set(__self__, "default_min_available_addr_num", default_min_available_addr_num)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "strategy_mode", strategy_mode)
        pulumi.set(__self__, "strategy_name", strategy_name)
        if access_mode is not None:
            pulumi.set(__self__, "access_mode", access_mode)
        if default_latency_optimization is not None:
            pulumi.set(__self__, "default_latency_optimization", default_latency_optimization)
        if default_lba_strategy is not None:
            pulumi.set(__self__, "default_lba_strategy", default_lba_strategy)
        if default_max_return_addr_num is not None:
            pulumi.set(__self__, "default_max_return_addr_num", default_max_return_addr_num)
        if failover_addr_pool_type is not None:
            pulumi.set(__self__, "failover_addr_pool_type", failover_addr_pool_type)
        if failover_addr_pools is not None:
            pulumi.set(__self__, "failover_addr_pools", failover_addr_pools)
        if failover_latency_optimization is not None:
            pulumi.set(__self__, "failover_latency_optimization", failover_latency_optimization)
        if failover_lba_strategy is not None:
            pulumi.set(__self__, "failover_lba_strategy", failover_lba_strategy)
        if failover_max_return_addr_num is not None:
            pulumi.set(__self__, "failover_max_return_addr_num", failover_max_return_addr_num)
        if failover_min_available_addr_num is not None:
            pulumi.set(__self__, "failover_min_available_addr_num", failover_min_available_addr_num)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if lines is not None:
            pulumi.set(__self__, "lines", lines)

    @property
    @pulumi.getter(name="defaultAddrPoolType")
    def default_addr_pool_type(self) -> pulumi.Input[str]:
        """
        The type of the primary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        """
        return pulumi.get(self, "default_addr_pool_type")

    @default_addr_pool_type.setter
    def default_addr_pool_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "default_addr_pool_type", value)

    @property
    @pulumi.getter(name="defaultAddrPools")
    def default_addr_pools(self) -> pulumi.Input[Sequence[pulumi.Input['AccessStrategyDefaultAddrPoolArgs']]]:
        """
        List of primary address pool collections. See `default_addr_pools` below for details.
        """
        return pulumi.get(self, "default_addr_pools")

    @default_addr_pools.setter
    def default_addr_pools(self, value: pulumi.Input[Sequence[pulumi.Input['AccessStrategyDefaultAddrPoolArgs']]]):
        pulumi.set(self, "default_addr_pools", value)

    @property
    @pulumi.getter(name="defaultMinAvailableAddrNum")
    def default_min_available_addr_num(self) -> pulumi.Input[int]:
        """
        The minimum number of available addresses for the primary address pool set.
        """
        return pulumi.get(self, "default_min_available_addr_num")

    @default_min_available_addr_num.setter
    def default_min_available_addr_num(self, value: pulumi.Input[int]):
        pulumi.set(self, "default_min_available_addr_num", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The Id of the associated instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="strategyMode")
    def strategy_mode(self) -> pulumi.Input[str]:
        """
        The type of the access policy. Valid values: `GEO` or `LATENCY`. `GEO`: based on geographic location. `LATENCY`: Based on delay.
        """
        return pulumi.get(self, "strategy_mode")

    @strategy_mode.setter
    def strategy_mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "strategy_mode", value)

    @property
    @pulumi.getter(name="strategyName")
    def strategy_name(self) -> pulumi.Input[str]:
        """
        The name of the access policy.
        """
        return pulumi.get(self, "strategy_name")

    @strategy_name.setter
    def strategy_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "strategy_name", value)

    @property
    @pulumi.getter(name="accessMode")
    def access_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The primary/secondary switchover policy for address pool groups. Valid values: `AUTO`, `DEFAULT`, `FAILOVER`.
        """
        return pulumi.get(self, "access_mode")

    @access_mode.setter
    def access_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_mode", value)

    @property
    @pulumi.getter(name="defaultLatencyOptimization")
    def default_latency_optimization(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to enable scheduling optimization for latency resolution for the primary address pool group. Valid values: `OPEN`, `CLOSE`.
        """
        return pulumi.get(self, "default_latency_optimization")

    @default_latency_optimization.setter
    def default_latency_optimization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_latency_optimization", value)

    @property
    @pulumi.getter(name="defaultLbaStrategy")
    def default_lba_strategy(self) -> Optional[pulumi.Input[str]]:
        """
        The load balancing policy of the primary address pool group. Valid values: `ALL_RR`, `RATIO`. **NOTE:** The `default_lba_strategy` is required under the condition that `strategy_mode` is `GEO`.
        """
        return pulumi.get(self, "default_lba_strategy")

    @default_lba_strategy.setter
    def default_lba_strategy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_lba_strategy", value)

    @property
    @pulumi.getter(name="defaultMaxReturnAddrNum")
    def default_max_return_addr_num(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of addresses returned by the primary address pool set. **NOTE:** The `default_max_return_addr_num` is required under the condition that `strategy_mode` is `LATENCY`.
        """
        return pulumi.get(self, "default_max_return_addr_num")

    @default_max_return_addr_num.setter
    def default_max_return_addr_num(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "default_max_return_addr_num", value)

    @property
    @pulumi.getter(name="failoverAddrPoolType")
    def failover_addr_pool_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the secondary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        """
        return pulumi.get(self, "failover_addr_pool_type")

    @failover_addr_pool_type.setter
    def failover_addr_pool_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "failover_addr_pool_type", value)

    @property
    @pulumi.getter(name="failoverAddrPools")
    def failover_addr_pools(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyFailoverAddrPoolArgs']]]]:
        """
        List of backup address pool sets. See `failover_addr_pools` below for details.
        """
        return pulumi.get(self, "failover_addr_pools")

    @failover_addr_pools.setter
    def failover_addr_pools(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyFailoverAddrPoolArgs']]]]):
        pulumi.set(self, "failover_addr_pools", value)

    @property
    @pulumi.getter(name="failoverLatencyOptimization")
    def failover_latency_optimization(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to enable scheduling optimization for latency resolution for the secondary address pool group. Valid values: `OPEN`, `CLOSE`.
        """
        return pulumi.get(self, "failover_latency_optimization")

    @failover_latency_optimization.setter
    def failover_latency_optimization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "failover_latency_optimization", value)

    @property
    @pulumi.getter(name="failoverLbaStrategy")
    def failover_lba_strategy(self) -> Optional[pulumi.Input[str]]:
        """
        The load balancing policy of the secondary address pool group. Valid values: `ALL_RR`, `RATIO`.
        """
        return pulumi.get(self, "failover_lba_strategy")

    @failover_lba_strategy.setter
    def failover_lba_strategy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "failover_lba_strategy", value)

    @property
    @pulumi.getter(name="failoverMaxReturnAddrNum")
    def failover_max_return_addr_num(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of returned addresses in the standby address pool.
        """
        return pulumi.get(self, "failover_max_return_addr_num")

    @failover_max_return_addr_num.setter
    def failover_max_return_addr_num(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "failover_max_return_addr_num", value)

    @property
    @pulumi.getter(name="failoverMinAvailableAddrNum")
    def failover_min_available_addr_num(self) -> Optional[pulumi.Input[int]]:
        """
        The minimum number of available addresses in the standby address pool.
        """
        return pulumi.get(self, "failover_min_available_addr_num")

    @failover_min_available_addr_num.setter
    def failover_min_available_addr_num(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "failover_min_available_addr_num", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        """
        The lang.
        """
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter
    def lines(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyLineArgs']]]]:
        """
        The source regions. See `lines` below for details. **NOTE:** The `lines` is required under the condition that `strategy_mode` is `GEO`.
        """
        return pulumi.get(self, "lines")

    @lines.setter
    def lines(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyLineArgs']]]]):
        pulumi.set(self, "lines", value)


@pulumi.input_type
class _AccessStrategyState:
    def __init__(__self__, *,
                 access_mode: Optional[pulumi.Input[str]] = None,
                 default_addr_pool_type: Optional[pulumi.Input[str]] = None,
                 default_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyDefaultAddrPoolArgs']]]] = None,
                 default_latency_optimization: Optional[pulumi.Input[str]] = None,
                 default_lba_strategy: Optional[pulumi.Input[str]] = None,
                 default_max_return_addr_num: Optional[pulumi.Input[int]] = None,
                 default_min_available_addr_num: Optional[pulumi.Input[int]] = None,
                 failover_addr_pool_type: Optional[pulumi.Input[str]] = None,
                 failover_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyFailoverAddrPoolArgs']]]] = None,
                 failover_latency_optimization: Optional[pulumi.Input[str]] = None,
                 failover_lba_strategy: Optional[pulumi.Input[str]] = None,
                 failover_max_return_addr_num: Optional[pulumi.Input[int]] = None,
                 failover_min_available_addr_num: Optional[pulumi.Input[int]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 lines: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyLineArgs']]]] = None,
                 strategy_mode: Optional[pulumi.Input[str]] = None,
                 strategy_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AccessStrategy resources.
        :param pulumi.Input[str] access_mode: The primary/secondary switchover policy for address pool groups. Valid values: `AUTO`, `DEFAULT`, `FAILOVER`.
        :param pulumi.Input[str] default_addr_pool_type: The type of the primary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        :param pulumi.Input[Sequence[pulumi.Input['AccessStrategyDefaultAddrPoolArgs']]] default_addr_pools: List of primary address pool collections. See `default_addr_pools` below for details.
        :param pulumi.Input[str] default_latency_optimization: Specifies whether to enable scheduling optimization for latency resolution for the primary address pool group. Valid values: `OPEN`, `CLOSE`.
        :param pulumi.Input[str] default_lba_strategy: The load balancing policy of the primary address pool group. Valid values: `ALL_RR`, `RATIO`. **NOTE:** The `default_lba_strategy` is required under the condition that `strategy_mode` is `GEO`.
        :param pulumi.Input[int] default_max_return_addr_num: The maximum number of addresses returned by the primary address pool set. **NOTE:** The `default_max_return_addr_num` is required under the condition that `strategy_mode` is `LATENCY`.
        :param pulumi.Input[int] default_min_available_addr_num: The minimum number of available addresses for the primary address pool set.
        :param pulumi.Input[str] failover_addr_pool_type: The type of the secondary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        :param pulumi.Input[Sequence[pulumi.Input['AccessStrategyFailoverAddrPoolArgs']]] failover_addr_pools: List of backup address pool sets. See `failover_addr_pools` below for details.
        :param pulumi.Input[str] failover_latency_optimization: Specifies whether to enable scheduling optimization for latency resolution for the secondary address pool group. Valid values: `OPEN`, `CLOSE`.
        :param pulumi.Input[str] failover_lba_strategy: The load balancing policy of the secondary address pool group. Valid values: `ALL_RR`, `RATIO`.
        :param pulumi.Input[int] failover_max_return_addr_num: The maximum number of returned addresses in the standby address pool.
        :param pulumi.Input[int] failover_min_available_addr_num: The minimum number of available addresses in the standby address pool.
        :param pulumi.Input[str] instance_id: The Id of the associated instance.
        :param pulumi.Input[str] lang: The lang.
        :param pulumi.Input[Sequence[pulumi.Input['AccessStrategyLineArgs']]] lines: The source regions. See `lines` below for details. **NOTE:** The `lines` is required under the condition that `strategy_mode` is `GEO`.
        :param pulumi.Input[str] strategy_mode: The type of the access policy. Valid values: `GEO` or `LATENCY`. `GEO`: based on geographic location. `LATENCY`: Based on delay.
        :param pulumi.Input[str] strategy_name: The name of the access policy.
        """
        if access_mode is not None:
            pulumi.set(__self__, "access_mode", access_mode)
        if default_addr_pool_type is not None:
            pulumi.set(__self__, "default_addr_pool_type", default_addr_pool_type)
        if default_addr_pools is not None:
            pulumi.set(__self__, "default_addr_pools", default_addr_pools)
        if default_latency_optimization is not None:
            pulumi.set(__self__, "default_latency_optimization", default_latency_optimization)
        if default_lba_strategy is not None:
            pulumi.set(__self__, "default_lba_strategy", default_lba_strategy)
        if default_max_return_addr_num is not None:
            pulumi.set(__self__, "default_max_return_addr_num", default_max_return_addr_num)
        if default_min_available_addr_num is not None:
            pulumi.set(__self__, "default_min_available_addr_num", default_min_available_addr_num)
        if failover_addr_pool_type is not None:
            pulumi.set(__self__, "failover_addr_pool_type", failover_addr_pool_type)
        if failover_addr_pools is not None:
            pulumi.set(__self__, "failover_addr_pools", failover_addr_pools)
        if failover_latency_optimization is not None:
            pulumi.set(__self__, "failover_latency_optimization", failover_latency_optimization)
        if failover_lba_strategy is not None:
            pulumi.set(__self__, "failover_lba_strategy", failover_lba_strategy)
        if failover_max_return_addr_num is not None:
            pulumi.set(__self__, "failover_max_return_addr_num", failover_max_return_addr_num)
        if failover_min_available_addr_num is not None:
            pulumi.set(__self__, "failover_min_available_addr_num", failover_min_available_addr_num)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if lines is not None:
            pulumi.set(__self__, "lines", lines)
        if strategy_mode is not None:
            pulumi.set(__self__, "strategy_mode", strategy_mode)
        if strategy_name is not None:
            pulumi.set(__self__, "strategy_name", strategy_name)

    @property
    @pulumi.getter(name="accessMode")
    def access_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The primary/secondary switchover policy for address pool groups. Valid values: `AUTO`, `DEFAULT`, `FAILOVER`.
        """
        return pulumi.get(self, "access_mode")

    @access_mode.setter
    def access_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_mode", value)

    @property
    @pulumi.getter(name="defaultAddrPoolType")
    def default_addr_pool_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the primary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        """
        return pulumi.get(self, "default_addr_pool_type")

    @default_addr_pool_type.setter
    def default_addr_pool_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_addr_pool_type", value)

    @property
    @pulumi.getter(name="defaultAddrPools")
    def default_addr_pools(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyDefaultAddrPoolArgs']]]]:
        """
        List of primary address pool collections. See `default_addr_pools` below for details.
        """
        return pulumi.get(self, "default_addr_pools")

    @default_addr_pools.setter
    def default_addr_pools(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyDefaultAddrPoolArgs']]]]):
        pulumi.set(self, "default_addr_pools", value)

    @property
    @pulumi.getter(name="defaultLatencyOptimization")
    def default_latency_optimization(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to enable scheduling optimization for latency resolution for the primary address pool group. Valid values: `OPEN`, `CLOSE`.
        """
        return pulumi.get(self, "default_latency_optimization")

    @default_latency_optimization.setter
    def default_latency_optimization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_latency_optimization", value)

    @property
    @pulumi.getter(name="defaultLbaStrategy")
    def default_lba_strategy(self) -> Optional[pulumi.Input[str]]:
        """
        The load balancing policy of the primary address pool group. Valid values: `ALL_RR`, `RATIO`. **NOTE:** The `default_lba_strategy` is required under the condition that `strategy_mode` is `GEO`.
        """
        return pulumi.get(self, "default_lba_strategy")

    @default_lba_strategy.setter
    def default_lba_strategy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_lba_strategy", value)

    @property
    @pulumi.getter(name="defaultMaxReturnAddrNum")
    def default_max_return_addr_num(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of addresses returned by the primary address pool set. **NOTE:** The `default_max_return_addr_num` is required under the condition that `strategy_mode` is `LATENCY`.
        """
        return pulumi.get(self, "default_max_return_addr_num")

    @default_max_return_addr_num.setter
    def default_max_return_addr_num(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "default_max_return_addr_num", value)

    @property
    @pulumi.getter(name="defaultMinAvailableAddrNum")
    def default_min_available_addr_num(self) -> Optional[pulumi.Input[int]]:
        """
        The minimum number of available addresses for the primary address pool set.
        """
        return pulumi.get(self, "default_min_available_addr_num")

    @default_min_available_addr_num.setter
    def default_min_available_addr_num(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "default_min_available_addr_num", value)

    @property
    @pulumi.getter(name="failoverAddrPoolType")
    def failover_addr_pool_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the secondary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        """
        return pulumi.get(self, "failover_addr_pool_type")

    @failover_addr_pool_type.setter
    def failover_addr_pool_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "failover_addr_pool_type", value)

    @property
    @pulumi.getter(name="failoverAddrPools")
    def failover_addr_pools(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyFailoverAddrPoolArgs']]]]:
        """
        List of backup address pool sets. See `failover_addr_pools` below for details.
        """
        return pulumi.get(self, "failover_addr_pools")

    @failover_addr_pools.setter
    def failover_addr_pools(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyFailoverAddrPoolArgs']]]]):
        pulumi.set(self, "failover_addr_pools", value)

    @property
    @pulumi.getter(name="failoverLatencyOptimization")
    def failover_latency_optimization(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to enable scheduling optimization for latency resolution for the secondary address pool group. Valid values: `OPEN`, `CLOSE`.
        """
        return pulumi.get(self, "failover_latency_optimization")

    @failover_latency_optimization.setter
    def failover_latency_optimization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "failover_latency_optimization", value)

    @property
    @pulumi.getter(name="failoverLbaStrategy")
    def failover_lba_strategy(self) -> Optional[pulumi.Input[str]]:
        """
        The load balancing policy of the secondary address pool group. Valid values: `ALL_RR`, `RATIO`.
        """
        return pulumi.get(self, "failover_lba_strategy")

    @failover_lba_strategy.setter
    def failover_lba_strategy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "failover_lba_strategy", value)

    @property
    @pulumi.getter(name="failoverMaxReturnAddrNum")
    def failover_max_return_addr_num(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of returned addresses in the standby address pool.
        """
        return pulumi.get(self, "failover_max_return_addr_num")

    @failover_max_return_addr_num.setter
    def failover_max_return_addr_num(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "failover_max_return_addr_num", value)

    @property
    @pulumi.getter(name="failoverMinAvailableAddrNum")
    def failover_min_available_addr_num(self) -> Optional[pulumi.Input[int]]:
        """
        The minimum number of available addresses in the standby address pool.
        """
        return pulumi.get(self, "failover_min_available_addr_num")

    @failover_min_available_addr_num.setter
    def failover_min_available_addr_num(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "failover_min_available_addr_num", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Id of the associated instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        """
        The lang.
        """
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter
    def lines(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyLineArgs']]]]:
        """
        The source regions. See `lines` below for details. **NOTE:** The `lines` is required under the condition that `strategy_mode` is `GEO`.
        """
        return pulumi.get(self, "lines")

    @lines.setter
    def lines(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AccessStrategyLineArgs']]]]):
        pulumi.set(self, "lines", value)

    @property
    @pulumi.getter(name="strategyMode")
    def strategy_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the access policy. Valid values: `GEO` or `LATENCY`. `GEO`: based on geographic location. `LATENCY`: Based on delay.
        """
        return pulumi.get(self, "strategy_mode")

    @strategy_mode.setter
    def strategy_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "strategy_mode", value)

    @property
    @pulumi.getter(name="strategyName")
    def strategy_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the access policy.
        """
        return pulumi.get(self, "strategy_name")

    @strategy_name.setter
    def strategy_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "strategy_name", value)


class AccessStrategy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_mode: Optional[pulumi.Input[str]] = None,
                 default_addr_pool_type: Optional[pulumi.Input[str]] = None,
                 default_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyDefaultAddrPoolArgs', 'AccessStrategyDefaultAddrPoolArgsDict']]]]] = None,
                 default_latency_optimization: Optional[pulumi.Input[str]] = None,
                 default_lba_strategy: Optional[pulumi.Input[str]] = None,
                 default_max_return_addr_num: Optional[pulumi.Input[int]] = None,
                 default_min_available_addr_num: Optional[pulumi.Input[int]] = None,
                 failover_addr_pool_type: Optional[pulumi.Input[str]] = None,
                 failover_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyFailoverAddrPoolArgs', 'AccessStrategyFailoverAddrPoolArgsDict']]]]] = None,
                 failover_latency_optimization: Optional[pulumi.Input[str]] = None,
                 failover_lba_strategy: Optional[pulumi.Input[str]] = None,
                 failover_max_return_addr_num: Optional[pulumi.Input[int]] = None,
                 failover_min_available_addr_num: Optional[pulumi.Input[int]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 lines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyLineArgs', 'AccessStrategyLineArgsDict']]]]] = None,
                 strategy_mode: Optional[pulumi.Input[str]] = None,
                 strategy_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a DNS Access Strategy resource.

        For information about DNS Access Strategy and how to use it, see [What is Access Strategy](https://www.alibabacloud.com/help/doc-detail/189620.html).

        > **NOTE:** Available since v1.152.0.

        ## Import

        DNS Access Strategy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dns/accessStrategy:AccessStrategy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_mode: The primary/secondary switchover policy for address pool groups. Valid values: `AUTO`, `DEFAULT`, `FAILOVER`.
        :param pulumi.Input[str] default_addr_pool_type: The type of the primary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyDefaultAddrPoolArgs', 'AccessStrategyDefaultAddrPoolArgsDict']]]] default_addr_pools: List of primary address pool collections. See `default_addr_pools` below for details.
        :param pulumi.Input[str] default_latency_optimization: Specifies whether to enable scheduling optimization for latency resolution for the primary address pool group. Valid values: `OPEN`, `CLOSE`.
        :param pulumi.Input[str] default_lba_strategy: The load balancing policy of the primary address pool group. Valid values: `ALL_RR`, `RATIO`. **NOTE:** The `default_lba_strategy` is required under the condition that `strategy_mode` is `GEO`.
        :param pulumi.Input[int] default_max_return_addr_num: The maximum number of addresses returned by the primary address pool set. **NOTE:** The `default_max_return_addr_num` is required under the condition that `strategy_mode` is `LATENCY`.
        :param pulumi.Input[int] default_min_available_addr_num: The minimum number of available addresses for the primary address pool set.
        :param pulumi.Input[str] failover_addr_pool_type: The type of the secondary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyFailoverAddrPoolArgs', 'AccessStrategyFailoverAddrPoolArgsDict']]]] failover_addr_pools: List of backup address pool sets. See `failover_addr_pools` below for details.
        :param pulumi.Input[str] failover_latency_optimization: Specifies whether to enable scheduling optimization for latency resolution for the secondary address pool group. Valid values: `OPEN`, `CLOSE`.
        :param pulumi.Input[str] failover_lba_strategy: The load balancing policy of the secondary address pool group. Valid values: `ALL_RR`, `RATIO`.
        :param pulumi.Input[int] failover_max_return_addr_num: The maximum number of returned addresses in the standby address pool.
        :param pulumi.Input[int] failover_min_available_addr_num: The minimum number of available addresses in the standby address pool.
        :param pulumi.Input[str] instance_id: The Id of the associated instance.
        :param pulumi.Input[str] lang: The lang.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyLineArgs', 'AccessStrategyLineArgsDict']]]] lines: The source regions. See `lines` below for details. **NOTE:** The `lines` is required under the condition that `strategy_mode` is `GEO`.
        :param pulumi.Input[str] strategy_mode: The type of the access policy. Valid values: `GEO` or `LATENCY`. `GEO`: based on geographic location. `LATENCY`: Based on delay.
        :param pulumi.Input[str] strategy_name: The name of the access policy.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccessStrategyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DNS Access Strategy resource.

        For information about DNS Access Strategy and how to use it, see [What is Access Strategy](https://www.alibabacloud.com/help/doc-detail/189620.html).

        > **NOTE:** Available since v1.152.0.

        ## Import

        DNS Access Strategy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dns/accessStrategy:AccessStrategy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AccessStrategyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccessStrategyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_mode: Optional[pulumi.Input[str]] = None,
                 default_addr_pool_type: Optional[pulumi.Input[str]] = None,
                 default_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyDefaultAddrPoolArgs', 'AccessStrategyDefaultAddrPoolArgsDict']]]]] = None,
                 default_latency_optimization: Optional[pulumi.Input[str]] = None,
                 default_lba_strategy: Optional[pulumi.Input[str]] = None,
                 default_max_return_addr_num: Optional[pulumi.Input[int]] = None,
                 default_min_available_addr_num: Optional[pulumi.Input[int]] = None,
                 failover_addr_pool_type: Optional[pulumi.Input[str]] = None,
                 failover_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyFailoverAddrPoolArgs', 'AccessStrategyFailoverAddrPoolArgsDict']]]]] = None,
                 failover_latency_optimization: Optional[pulumi.Input[str]] = None,
                 failover_lba_strategy: Optional[pulumi.Input[str]] = None,
                 failover_max_return_addr_num: Optional[pulumi.Input[int]] = None,
                 failover_min_available_addr_num: Optional[pulumi.Input[int]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 lines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyLineArgs', 'AccessStrategyLineArgsDict']]]]] = None,
                 strategy_mode: Optional[pulumi.Input[str]] = None,
                 strategy_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccessStrategyArgs.__new__(AccessStrategyArgs)

            __props__.__dict__["access_mode"] = access_mode
            if default_addr_pool_type is None and not opts.urn:
                raise TypeError("Missing required property 'default_addr_pool_type'")
            __props__.__dict__["default_addr_pool_type"] = default_addr_pool_type
            if default_addr_pools is None and not opts.urn:
                raise TypeError("Missing required property 'default_addr_pools'")
            __props__.__dict__["default_addr_pools"] = default_addr_pools
            __props__.__dict__["default_latency_optimization"] = default_latency_optimization
            __props__.__dict__["default_lba_strategy"] = default_lba_strategy
            __props__.__dict__["default_max_return_addr_num"] = default_max_return_addr_num
            if default_min_available_addr_num is None and not opts.urn:
                raise TypeError("Missing required property 'default_min_available_addr_num'")
            __props__.__dict__["default_min_available_addr_num"] = default_min_available_addr_num
            __props__.__dict__["failover_addr_pool_type"] = failover_addr_pool_type
            __props__.__dict__["failover_addr_pools"] = failover_addr_pools
            __props__.__dict__["failover_latency_optimization"] = failover_latency_optimization
            __props__.__dict__["failover_lba_strategy"] = failover_lba_strategy
            __props__.__dict__["failover_max_return_addr_num"] = failover_max_return_addr_num
            __props__.__dict__["failover_min_available_addr_num"] = failover_min_available_addr_num
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["lang"] = lang
            __props__.__dict__["lines"] = lines
            if strategy_mode is None and not opts.urn:
                raise TypeError("Missing required property 'strategy_mode'")
            __props__.__dict__["strategy_mode"] = strategy_mode
            if strategy_name is None and not opts.urn:
                raise TypeError("Missing required property 'strategy_name'")
            __props__.__dict__["strategy_name"] = strategy_name
        super(AccessStrategy, __self__).__init__(
            'alicloud:dns/accessStrategy:AccessStrategy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_mode: Optional[pulumi.Input[str]] = None,
            default_addr_pool_type: Optional[pulumi.Input[str]] = None,
            default_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyDefaultAddrPoolArgs', 'AccessStrategyDefaultAddrPoolArgsDict']]]]] = None,
            default_latency_optimization: Optional[pulumi.Input[str]] = None,
            default_lba_strategy: Optional[pulumi.Input[str]] = None,
            default_max_return_addr_num: Optional[pulumi.Input[int]] = None,
            default_min_available_addr_num: Optional[pulumi.Input[int]] = None,
            failover_addr_pool_type: Optional[pulumi.Input[str]] = None,
            failover_addr_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyFailoverAddrPoolArgs', 'AccessStrategyFailoverAddrPoolArgsDict']]]]] = None,
            failover_latency_optimization: Optional[pulumi.Input[str]] = None,
            failover_lba_strategy: Optional[pulumi.Input[str]] = None,
            failover_max_return_addr_num: Optional[pulumi.Input[int]] = None,
            failover_min_available_addr_num: Optional[pulumi.Input[int]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            lang: Optional[pulumi.Input[str]] = None,
            lines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyLineArgs', 'AccessStrategyLineArgsDict']]]]] = None,
            strategy_mode: Optional[pulumi.Input[str]] = None,
            strategy_name: Optional[pulumi.Input[str]] = None) -> 'AccessStrategy':
        """
        Get an existing AccessStrategy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_mode: The primary/secondary switchover policy for address pool groups. Valid values: `AUTO`, `DEFAULT`, `FAILOVER`.
        :param pulumi.Input[str] default_addr_pool_type: The type of the primary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyDefaultAddrPoolArgs', 'AccessStrategyDefaultAddrPoolArgsDict']]]] default_addr_pools: List of primary address pool collections. See `default_addr_pools` below for details.
        :param pulumi.Input[str] default_latency_optimization: Specifies whether to enable scheduling optimization for latency resolution for the primary address pool group. Valid values: `OPEN`, `CLOSE`.
        :param pulumi.Input[str] default_lba_strategy: The load balancing policy of the primary address pool group. Valid values: `ALL_RR`, `RATIO`. **NOTE:** The `default_lba_strategy` is required under the condition that `strategy_mode` is `GEO`.
        :param pulumi.Input[int] default_max_return_addr_num: The maximum number of addresses returned by the primary address pool set. **NOTE:** The `default_max_return_addr_num` is required under the condition that `strategy_mode` is `LATENCY`.
        :param pulumi.Input[int] default_min_available_addr_num: The minimum number of available addresses for the primary address pool set.
        :param pulumi.Input[str] failover_addr_pool_type: The type of the secondary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyFailoverAddrPoolArgs', 'AccessStrategyFailoverAddrPoolArgsDict']]]] failover_addr_pools: List of backup address pool sets. See `failover_addr_pools` below for details.
        :param pulumi.Input[str] failover_latency_optimization: Specifies whether to enable scheduling optimization for latency resolution for the secondary address pool group. Valid values: `OPEN`, `CLOSE`.
        :param pulumi.Input[str] failover_lba_strategy: The load balancing policy of the secondary address pool group. Valid values: `ALL_RR`, `RATIO`.
        :param pulumi.Input[int] failover_max_return_addr_num: The maximum number of returned addresses in the standby address pool.
        :param pulumi.Input[int] failover_min_available_addr_num: The minimum number of available addresses in the standby address pool.
        :param pulumi.Input[str] instance_id: The Id of the associated instance.
        :param pulumi.Input[str] lang: The lang.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AccessStrategyLineArgs', 'AccessStrategyLineArgsDict']]]] lines: The source regions. See `lines` below for details. **NOTE:** The `lines` is required under the condition that `strategy_mode` is `GEO`.
        :param pulumi.Input[str] strategy_mode: The type of the access policy. Valid values: `GEO` or `LATENCY`. `GEO`: based on geographic location. `LATENCY`: Based on delay.
        :param pulumi.Input[str] strategy_name: The name of the access policy.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccessStrategyState.__new__(_AccessStrategyState)

        __props__.__dict__["access_mode"] = access_mode
        __props__.__dict__["default_addr_pool_type"] = default_addr_pool_type
        __props__.__dict__["default_addr_pools"] = default_addr_pools
        __props__.__dict__["default_latency_optimization"] = default_latency_optimization
        __props__.__dict__["default_lba_strategy"] = default_lba_strategy
        __props__.__dict__["default_max_return_addr_num"] = default_max_return_addr_num
        __props__.__dict__["default_min_available_addr_num"] = default_min_available_addr_num
        __props__.__dict__["failover_addr_pool_type"] = failover_addr_pool_type
        __props__.__dict__["failover_addr_pools"] = failover_addr_pools
        __props__.__dict__["failover_latency_optimization"] = failover_latency_optimization
        __props__.__dict__["failover_lba_strategy"] = failover_lba_strategy
        __props__.__dict__["failover_max_return_addr_num"] = failover_max_return_addr_num
        __props__.__dict__["failover_min_available_addr_num"] = failover_min_available_addr_num
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["lang"] = lang
        __props__.__dict__["lines"] = lines
        __props__.__dict__["strategy_mode"] = strategy_mode
        __props__.__dict__["strategy_name"] = strategy_name
        return AccessStrategy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessMode")
    def access_mode(self) -> pulumi.Output[str]:
        """
        The primary/secondary switchover policy for address pool groups. Valid values: `AUTO`, `DEFAULT`, `FAILOVER`.
        """
        return pulumi.get(self, "access_mode")

    @property
    @pulumi.getter(name="defaultAddrPoolType")
    def default_addr_pool_type(self) -> pulumi.Output[str]:
        """
        The type of the primary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        """
        return pulumi.get(self, "default_addr_pool_type")

    @property
    @pulumi.getter(name="defaultAddrPools")
    def default_addr_pools(self) -> pulumi.Output[Sequence['outputs.AccessStrategyDefaultAddrPool']]:
        """
        List of primary address pool collections. See `default_addr_pools` below for details.
        """
        return pulumi.get(self, "default_addr_pools")

    @property
    @pulumi.getter(name="defaultLatencyOptimization")
    def default_latency_optimization(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies whether to enable scheduling optimization for latency resolution for the primary address pool group. Valid values: `OPEN`, `CLOSE`.
        """
        return pulumi.get(self, "default_latency_optimization")

    @property
    @pulumi.getter(name="defaultLbaStrategy")
    def default_lba_strategy(self) -> pulumi.Output[Optional[str]]:
        """
        The load balancing policy of the primary address pool group. Valid values: `ALL_RR`, `RATIO`. **NOTE:** The `default_lba_strategy` is required under the condition that `strategy_mode` is `GEO`.
        """
        return pulumi.get(self, "default_lba_strategy")

    @property
    @pulumi.getter(name="defaultMaxReturnAddrNum")
    def default_max_return_addr_num(self) -> pulumi.Output[Optional[int]]:
        """
        The maximum number of addresses returned by the primary address pool set. **NOTE:** The `default_max_return_addr_num` is required under the condition that `strategy_mode` is `LATENCY`.
        """
        return pulumi.get(self, "default_max_return_addr_num")

    @property
    @pulumi.getter(name="defaultMinAvailableAddrNum")
    def default_min_available_addr_num(self) -> pulumi.Output[int]:
        """
        The minimum number of available addresses for the primary address pool set.
        """
        return pulumi.get(self, "default_min_available_addr_num")

    @property
    @pulumi.getter(name="failoverAddrPoolType")
    def failover_addr_pool_type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of the secondary address pool. Valid values: `IPV4`, `IPV6`, `DOMAIN`.
        """
        return pulumi.get(self, "failover_addr_pool_type")

    @property
    @pulumi.getter(name="failoverAddrPools")
    def failover_addr_pools(self) -> pulumi.Output[Optional[Sequence['outputs.AccessStrategyFailoverAddrPool']]]:
        """
        List of backup address pool sets. See `failover_addr_pools` below for details.
        """
        return pulumi.get(self, "failover_addr_pools")

    @property
    @pulumi.getter(name="failoverLatencyOptimization")
    def failover_latency_optimization(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies whether to enable scheduling optimization for latency resolution for the secondary address pool group. Valid values: `OPEN`, `CLOSE`.
        """
        return pulumi.get(self, "failover_latency_optimization")

    @property
    @pulumi.getter(name="failoverLbaStrategy")
    def failover_lba_strategy(self) -> pulumi.Output[Optional[str]]:
        """
        The load balancing policy of the secondary address pool group. Valid values: `ALL_RR`, `RATIO`.
        """
        return pulumi.get(self, "failover_lba_strategy")

    @property
    @pulumi.getter(name="failoverMaxReturnAddrNum")
    def failover_max_return_addr_num(self) -> pulumi.Output[Optional[int]]:
        """
        The maximum number of returned addresses in the standby address pool.
        """
        return pulumi.get(self, "failover_max_return_addr_num")

    @property
    @pulumi.getter(name="failoverMinAvailableAddrNum")
    def failover_min_available_addr_num(self) -> pulumi.Output[Optional[int]]:
        """
        The minimum number of available addresses in the standby address pool.
        """
        return pulumi.get(self, "failover_min_available_addr_num")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The Id of the associated instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def lang(self) -> pulumi.Output[Optional[str]]:
        """
        The lang.
        """
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter
    def lines(self) -> pulumi.Output[Optional[Sequence['outputs.AccessStrategyLine']]]:
        """
        The source regions. See `lines` below for details. **NOTE:** The `lines` is required under the condition that `strategy_mode` is `GEO`.
        """
        return pulumi.get(self, "lines")

    @property
    @pulumi.getter(name="strategyMode")
    def strategy_mode(self) -> pulumi.Output[str]:
        """
        The type of the access policy. Valid values: `GEO` or `LATENCY`. `GEO`: based on geographic location. `LATENCY`: Based on delay.
        """
        return pulumi.get(self, "strategy_mode")

    @property
    @pulumi.getter(name="strategyName")
    def strategy_name(self) -> pulumi.Output[str]:
        """
        The name of the access policy.
        """
        return pulumi.get(self, "strategy_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RouterVbrChildInstanceArgs', 'RouterVbrChildInstance']

@pulumi.input_type
class RouterVbrChildInstanceArgs:
    def __init__(__self__, *,
                 child_instance_id: pulumi.Input[str],
                 child_instance_region_id: pulumi.Input[str],
                 child_instance_type: pulumi.Input[str],
                 ecr_id: pulumi.Input[str],
                 child_instance_owner_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a RouterVbrChildInstance resource.
        :param pulumi.Input[str] child_instance_id: The ID of the leased line gateway subinstance.
        :param pulumi.Input[str] child_instance_region_id: Region of the leased line gateway sub-instance.
        :param pulumi.Input[str] child_instance_type: The type of leased line gateway sub-instance, Valid values: `VBR`.
        :param pulumi.Input[str] ecr_id: ID of the representative leased line gateway instance.
        :param pulumi.Input[str] child_instance_owner_id: The ID of the subinstance of the leased line gateway.
        """
        pulumi.set(__self__, "child_instance_id", child_instance_id)
        pulumi.set(__self__, "child_instance_region_id", child_instance_region_id)
        pulumi.set(__self__, "child_instance_type", child_instance_type)
        pulumi.set(__self__, "ecr_id", ecr_id)
        if child_instance_owner_id is not None:
            pulumi.set(__self__, "child_instance_owner_id", child_instance_owner_id)

    @property
    @pulumi.getter(name="childInstanceId")
    def child_instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the leased line gateway subinstance.
        """
        return pulumi.get(self, "child_instance_id")

    @child_instance_id.setter
    def child_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "child_instance_id", value)

    @property
    @pulumi.getter(name="childInstanceRegionId")
    def child_instance_region_id(self) -> pulumi.Input[str]:
        """
        Region of the leased line gateway sub-instance.
        """
        return pulumi.get(self, "child_instance_region_id")

    @child_instance_region_id.setter
    def child_instance_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "child_instance_region_id", value)

    @property
    @pulumi.getter(name="childInstanceType")
    def child_instance_type(self) -> pulumi.Input[str]:
        """
        The type of leased line gateway sub-instance, Valid values: `VBR`.
        """
        return pulumi.get(self, "child_instance_type")

    @child_instance_type.setter
    def child_instance_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "child_instance_type", value)

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> pulumi.Input[str]:
        """
        ID of the representative leased line gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @ecr_id.setter
    def ecr_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "ecr_id", value)

    @property
    @pulumi.getter(name="childInstanceOwnerId")
    def child_instance_owner_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the subinstance of the leased line gateway.
        """
        return pulumi.get(self, "child_instance_owner_id")

    @child_instance_owner_id.setter
    def child_instance_owner_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "child_instance_owner_id", value)


@pulumi.input_type
class _RouterVbrChildInstanceState:
    def __init__(__self__, *,
                 child_instance_id: Optional[pulumi.Input[str]] = None,
                 child_instance_owner_id: Optional[pulumi.Input[str]] = None,
                 child_instance_region_id: Optional[pulumi.Input[str]] = None,
                 child_instance_type: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 ecr_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RouterVbrChildInstance resources.
        :param pulumi.Input[str] child_instance_id: The ID of the leased line gateway subinstance.
        :param pulumi.Input[str] child_instance_owner_id: The ID of the subinstance of the leased line gateway.
        :param pulumi.Input[str] child_instance_region_id: Region of the leased line gateway sub-instance.
        :param pulumi.Input[str] child_instance_type: The type of leased line gateway sub-instance, Valid values: `VBR`.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] ecr_id: ID of the representative leased line gateway instance.
        :param pulumi.Input[str] status: Binding relationship status of leased line gateway subinstances.
        """
        if child_instance_id is not None:
            pulumi.set(__self__, "child_instance_id", child_instance_id)
        if child_instance_owner_id is not None:
            pulumi.set(__self__, "child_instance_owner_id", child_instance_owner_id)
        if child_instance_region_id is not None:
            pulumi.set(__self__, "child_instance_region_id", child_instance_region_id)
        if child_instance_type is not None:
            pulumi.set(__self__, "child_instance_type", child_instance_type)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if ecr_id is not None:
            pulumi.set(__self__, "ecr_id", ecr_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="childInstanceId")
    def child_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the leased line gateway subinstance.
        """
        return pulumi.get(self, "child_instance_id")

    @child_instance_id.setter
    def child_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "child_instance_id", value)

    @property
    @pulumi.getter(name="childInstanceOwnerId")
    def child_instance_owner_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the subinstance of the leased line gateway.
        """
        return pulumi.get(self, "child_instance_owner_id")

    @child_instance_owner_id.setter
    def child_instance_owner_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "child_instance_owner_id", value)

    @property
    @pulumi.getter(name="childInstanceRegionId")
    def child_instance_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        Region of the leased line gateway sub-instance.
        """
        return pulumi.get(self, "child_instance_region_id")

    @child_instance_region_id.setter
    def child_instance_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "child_instance_region_id", value)

    @property
    @pulumi.getter(name="childInstanceType")
    def child_instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of leased line gateway sub-instance, Valid values: `VBR`.
        """
        return pulumi.get(self, "child_instance_type")

    @child_instance_type.setter
    def child_instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "child_instance_type", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the representative leased line gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @ecr_id.setter
    def ecr_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ecr_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Binding relationship status of leased line gateway subinstances.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class RouterVbrChildInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 child_instance_id: Optional[pulumi.Input[str]] = None,
                 child_instance_owner_id: Optional[pulumi.Input[str]] = None,
                 child_instance_region_id: Optional[pulumi.Input[str]] = None,
                 child_instance_type: Optional[pulumi.Input[str]] = None,
                 ecr_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Express Connect Router Express Connect Router Vbr Child Instance resource. Leased Line Gateway VBR sub-instance.

        For information about Express Connect Router Express Connect Router Vbr Child Instance and how to use it, see [What is Express Connect Router Vbr Child Instance](https://next.api.alibabacloud.com/api/ExpressConnectRouter/2023-09-01/AttachExpressConnectRouterChildInstance).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        name_regex = alicloud.expressconnect.get_physical_connections(name_regex="^preserved-NODELETING")
        defaultydbbk3 = alicloud.expressconnect.VirtualBorderRouter("defaultydbbk3",
            physical_connection_id=name_regex.connections[0].id,
            vlan_id=1000,
            peer_gateway_ip="192.168.254.2",
            peering_subnet_mask="255.255.255.0",
            local_gateway_ip="192.168.254.1")
        default_a_alh_uy = alicloud.expressconnect.RouterExpressConnectRouter("defaultAAlhUy", alibaba_side_asn=65532)
        current = alicloud.get_account()
        default = alicloud.expressconnect.RouterVbrChildInstance("default",
            child_instance_id=defaultydbbk3.id,
            child_instance_region_id="cn-hangzhou",
            ecr_id=default_a_alh_uy.id,
            child_instance_type="VBR",
            child_instance_owner_id=current.id)
        ```

        ## Import

        Express Connect Router Express Connect Router Vbr Child Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/routerVbrChildInstance:RouterVbrChildInstance example <ecr_id>:<child_instance_id>:<child_instance_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] child_instance_id: The ID of the leased line gateway subinstance.
        :param pulumi.Input[str] child_instance_owner_id: The ID of the subinstance of the leased line gateway.
        :param pulumi.Input[str] child_instance_region_id: Region of the leased line gateway sub-instance.
        :param pulumi.Input[str] child_instance_type: The type of leased line gateway sub-instance, Valid values: `VBR`.
        :param pulumi.Input[str] ecr_id: ID of the representative leased line gateway instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouterVbrChildInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Router Express Connect Router Vbr Child Instance resource. Leased Line Gateway VBR sub-instance.

        For information about Express Connect Router Express Connect Router Vbr Child Instance and how to use it, see [What is Express Connect Router Vbr Child Instance](https://next.api.alibabacloud.com/api/ExpressConnectRouter/2023-09-01/AttachExpressConnectRouterChildInstance).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        name_regex = alicloud.expressconnect.get_physical_connections(name_regex="^preserved-NODELETING")
        defaultydbbk3 = alicloud.expressconnect.VirtualBorderRouter("defaultydbbk3",
            physical_connection_id=name_regex.connections[0].id,
            vlan_id=1000,
            peer_gateway_ip="192.168.254.2",
            peering_subnet_mask="255.255.255.0",
            local_gateway_ip="192.168.254.1")
        default_a_alh_uy = alicloud.expressconnect.RouterExpressConnectRouter("defaultAAlhUy", alibaba_side_asn=65532)
        current = alicloud.get_account()
        default = alicloud.expressconnect.RouterVbrChildInstance("default",
            child_instance_id=defaultydbbk3.id,
            child_instance_region_id="cn-hangzhou",
            ecr_id=default_a_alh_uy.id,
            child_instance_type="VBR",
            child_instance_owner_id=current.id)
        ```

        ## Import

        Express Connect Router Express Connect Router Vbr Child Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/routerVbrChildInstance:RouterVbrChildInstance example <ecr_id>:<child_instance_id>:<child_instance_type>
        ```

        :param str resource_name: The name of the resource.
        :param RouterVbrChildInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouterVbrChildInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 child_instance_id: Optional[pulumi.Input[str]] = None,
                 child_instance_owner_id: Optional[pulumi.Input[str]] = None,
                 child_instance_region_id: Optional[pulumi.Input[str]] = None,
                 child_instance_type: Optional[pulumi.Input[str]] = None,
                 ecr_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouterVbrChildInstanceArgs.__new__(RouterVbrChildInstanceArgs)

            if child_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'child_instance_id'")
            __props__.__dict__["child_instance_id"] = child_instance_id
            __props__.__dict__["child_instance_owner_id"] = child_instance_owner_id
            if child_instance_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'child_instance_region_id'")
            __props__.__dict__["child_instance_region_id"] = child_instance_region_id
            if child_instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'child_instance_type'")
            __props__.__dict__["child_instance_type"] = child_instance_type
            if ecr_id is None and not opts.urn:
                raise TypeError("Missing required property 'ecr_id'")
            __props__.__dict__["ecr_id"] = ecr_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(RouterVbrChildInstance, __self__).__init__(
            'alicloud:expressconnect/routerVbrChildInstance:RouterVbrChildInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            child_instance_id: Optional[pulumi.Input[str]] = None,
            child_instance_owner_id: Optional[pulumi.Input[str]] = None,
            child_instance_region_id: Optional[pulumi.Input[str]] = None,
            child_instance_type: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            ecr_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'RouterVbrChildInstance':
        """
        Get an existing RouterVbrChildInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] child_instance_id: The ID of the leased line gateway subinstance.
        :param pulumi.Input[str] child_instance_owner_id: The ID of the subinstance of the leased line gateway.
        :param pulumi.Input[str] child_instance_region_id: Region of the leased line gateway sub-instance.
        :param pulumi.Input[str] child_instance_type: The type of leased line gateway sub-instance, Valid values: `VBR`.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] ecr_id: ID of the representative leased line gateway instance.
        :param pulumi.Input[str] status: Binding relationship status of leased line gateway subinstances.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RouterVbrChildInstanceState.__new__(_RouterVbrChildInstanceState)

        __props__.__dict__["child_instance_id"] = child_instance_id
        __props__.__dict__["child_instance_owner_id"] = child_instance_owner_id
        __props__.__dict__["child_instance_region_id"] = child_instance_region_id
        __props__.__dict__["child_instance_type"] = child_instance_type
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["ecr_id"] = ecr_id
        __props__.__dict__["status"] = status
        return RouterVbrChildInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="childInstanceId")
    def child_instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the leased line gateway subinstance.
        """
        return pulumi.get(self, "child_instance_id")

    @property
    @pulumi.getter(name="childInstanceOwnerId")
    def child_instance_owner_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the subinstance of the leased line gateway.
        """
        return pulumi.get(self, "child_instance_owner_id")

    @property
    @pulumi.getter(name="childInstanceRegionId")
    def child_instance_region_id(self) -> pulumi.Output[str]:
        """
        Region of the leased line gateway sub-instance.
        """
        return pulumi.get(self, "child_instance_region_id")

    @property
    @pulumi.getter(name="childInstanceType")
    def child_instance_type(self) -> pulumi.Output[str]:
        """
        The type of leased line gateway sub-instance, Valid values: `VBR`.
        """
        return pulumi.get(self, "child_instance_type")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="ecrId")
    def ecr_id(self) -> pulumi.Output[str]:
        """
        ID of the representative leased line gateway instance.
        """
        return pulumi.get(self, "ecr_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Binding relationship status of leased line gateway subinstances.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetProtocolsResult',
    'AwaitableGetProtocolsResult',
    'get_protocols',
    'get_protocols_output',
]

@pulumi.output_type
class GetProtocolsResult:
    """
    A collection of values returned by getProtocols.
    """
    def __init__(__self__, id=None, output_file=None, protocols=None, type=None, zone_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if protocols and not isinstance(protocols, list):
            raise TypeError("Expected argument 'protocols' to be a list")
        pulumi.set(__self__, "protocols", protocols)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def protocols(self) -> Sequence[str]:
        """
        A list of supported protocol type..
        """
        return pulumi.get(self, "protocols")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[str]:
        return pulumi.get(self, "zone_id")


class AwaitableGetProtocolsResult(GetProtocolsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProtocolsResult(
            id=self.id,
            output_file=self.output_file,
            protocols=self.protocols,
            type=self.type,
            zone_id=self.zone_id)


def get_protocols(output_file: Optional[str] = None,
                  type: Optional[str] = None,
                  zone_id: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProtocolsResult:
    """
    Provide  a data source to retrieve the type of protocol used to create NAS file system.

    > **NOTE:** Available in 1.42.0

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.nas.get_protocols(type="Performance",
        zone_id="cn-beijing-e",
        output_file="protocols.txt")
    pulumi.export("nasProtocolsProtocol", default.protocols[0])
    ```


    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str type: The file system type. Valid Values: `Performance` and `Capacity`.
    :param str zone_id: String to filter results by zone id.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    __args__['type'] = type
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:nas/getProtocols:getProtocols', __args__, opts=opts, typ=GetProtocolsResult).value

    return AwaitableGetProtocolsResult(
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        protocols=pulumi.get(__ret__, 'protocols'),
        type=pulumi.get(__ret__, 'type'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_protocols_output(output_file: Optional[pulumi.Input[Optional[str]]] = None,
                         type: Optional[pulumi.Input[str]] = None,
                         zone_id: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetProtocolsResult]:
    """
    Provide  a data source to retrieve the type of protocol used to create NAS file system.

    > **NOTE:** Available in 1.42.0

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.nas.get_protocols(type="Performance",
        zone_id="cn-beijing-e",
        output_file="protocols.txt")
    pulumi.export("nasProtocolsProtocol", default.protocols[0])
    ```


    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str type: The file system type. Valid Values: `Performance` and `Capacity`.
    :param str zone_id: String to filter results by zone id.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    __args__['type'] = type
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:nas/getProtocols:getProtocols', __args__, opts=opts, typ=GetProtocolsResult)
    return __ret__.apply(lambda __response__: GetProtocolsResult(
        id=pulumi.get(__response__, 'id'),
        output_file=pulumi.get(__response__, 'output_file'),
        protocols=pulumi.get(__response__, 'protocols'),
        type=pulumi.get(__response__, 'type'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EnterpriseLogicDatabaseArgs', 'EnterpriseLogicDatabase']

@pulumi.input_type
class EnterpriseLogicDatabaseArgs:
    def __init__(__self__, *,
                 alias: pulumi.Input[str],
                 database_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 logic_database_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a EnterpriseLogicDatabase resource.
        :param pulumi.Input[str] alias: Logical Library alias.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] database_ids: Sub-Database ID
        :param pulumi.Input[str] logic_database_id: The ID of the logical Library.
        """
        pulumi.set(__self__, "alias", alias)
        pulumi.set(__self__, "database_ids", database_ids)
        if logic_database_id is not None:
            pulumi.set(__self__, "logic_database_id", logic_database_id)

    @property
    @pulumi.getter
    def alias(self) -> pulumi.Input[str]:
        """
        Logical Library alias.
        """
        return pulumi.get(self, "alias")

    @alias.setter
    def alias(self, value: pulumi.Input[str]):
        pulumi.set(self, "alias", value)

    @property
    @pulumi.getter(name="databaseIds")
    def database_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Sub-Database ID
        """
        return pulumi.get(self, "database_ids")

    @database_ids.setter
    def database_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "database_ids", value)

    @property
    @pulumi.getter(name="logicDatabaseId")
    def logic_database_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the logical Library.
        """
        return pulumi.get(self, "logic_database_id")

    @logic_database_id.setter
    def logic_database_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logic_database_id", value)


@pulumi.input_type
class _EnterpriseLogicDatabaseState:
    def __init__(__self__, *,
                 alias: Optional[pulumi.Input[str]] = None,
                 database_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 db_type: Optional[pulumi.Input[str]] = None,
                 env_type: Optional[pulumi.Input[str]] = None,
                 logic: Optional[pulumi.Input[bool]] = None,
                 logic_database_id: Optional[pulumi.Input[str]] = None,
                 owner_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 owner_name_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 search_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EnterpriseLogicDatabase resources.
        :param pulumi.Input[str] alias: Logical Library alias.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] database_ids: Sub-Database ID
        :param pulumi.Input[str] db_type: Database type.
        :param pulumi.Input[str] env_type: Environment type, return value is as follows:-product: production environment-dev: development environment-pre: Advance Environment-test: test environment-sit:SIT environment-uat:UAT environment-pet: Pressure measurement environment-stag:STAG environment
        :param pulumi.Input[bool] logic: Whether it is a logical Library, the return value is true.
        :param pulumi.Input[str] logic_database_id: The ID of the logical Library.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] owner_id_lists: The user ID list of the logical library Owner.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] owner_name_lists: The nickname list of the logical library Owner.
        :param pulumi.Input[str] schema_name: Logical Library name.
        :param pulumi.Input[str] search_name: Logical library search name.
        """
        if alias is not None:
            pulumi.set(__self__, "alias", alias)
        if database_ids is not None:
            pulumi.set(__self__, "database_ids", database_ids)
        if db_type is not None:
            pulumi.set(__self__, "db_type", db_type)
        if env_type is not None:
            pulumi.set(__self__, "env_type", env_type)
        if logic is not None:
            pulumi.set(__self__, "logic", logic)
        if logic_database_id is not None:
            pulumi.set(__self__, "logic_database_id", logic_database_id)
        if owner_id_lists is not None:
            pulumi.set(__self__, "owner_id_lists", owner_id_lists)
        if owner_name_lists is not None:
            pulumi.set(__self__, "owner_name_lists", owner_name_lists)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if search_name is not None:
            pulumi.set(__self__, "search_name", search_name)

    @property
    @pulumi.getter
    def alias(self) -> Optional[pulumi.Input[str]]:
        """
        Logical Library alias.
        """
        return pulumi.get(self, "alias")

    @alias.setter
    def alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alias", value)

    @property
    @pulumi.getter(name="databaseIds")
    def database_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Sub-Database ID
        """
        return pulumi.get(self, "database_ids")

    @database_ids.setter
    def database_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "database_ids", value)

    @property
    @pulumi.getter(name="dbType")
    def db_type(self) -> Optional[pulumi.Input[str]]:
        """
        Database type.
        """
        return pulumi.get(self, "db_type")

    @db_type.setter
    def db_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "db_type", value)

    @property
    @pulumi.getter(name="envType")
    def env_type(self) -> Optional[pulumi.Input[str]]:
        """
        Environment type, return value is as follows:-product: production environment-dev: development environment-pre: Advance Environment-test: test environment-sit:SIT environment-uat:UAT environment-pet: Pressure measurement environment-stag:STAG environment
        """
        return pulumi.get(self, "env_type")

    @env_type.setter
    def env_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "env_type", value)

    @property
    @pulumi.getter
    def logic(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether it is a logical Library, the return value is true.
        """
        return pulumi.get(self, "logic")

    @logic.setter
    def logic(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "logic", value)

    @property
    @pulumi.getter(name="logicDatabaseId")
    def logic_database_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the logical Library.
        """
        return pulumi.get(self, "logic_database_id")

    @logic_database_id.setter
    def logic_database_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logic_database_id", value)

    @property
    @pulumi.getter(name="ownerIdLists")
    def owner_id_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The user ID list of the logical library Owner.
        """
        return pulumi.get(self, "owner_id_lists")

    @owner_id_lists.setter
    def owner_id_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "owner_id_lists", value)

    @property
    @pulumi.getter(name="ownerNameLists")
    def owner_name_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The nickname list of the logical library Owner.
        """
        return pulumi.get(self, "owner_name_lists")

    @owner_name_lists.setter
    def owner_name_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "owner_name_lists", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        Logical Library name.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="searchName")
    def search_name(self) -> Optional[pulumi.Input[str]]:
        """
        Logical library search name.
        """
        return pulumi.get(self, "search_name")

    @search_name.setter
    def search_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "search_name", value)


class EnterpriseLogicDatabase(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias: Optional[pulumi.Input[str]] = None,
                 database_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 logic_database_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a DMS Enterprise Logic Database resource.

        For information about DMS Enterprise Logic Database and how to use it, see [What is Logic Database](https://www.alibabacloud.com/help/en/dms/developer-reference/api-dms-enterprise-2018-11-01-createlogicdatabase).

        > **NOTE:** Available in v1.195.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.dms.EnterpriseLogicDatabase("default",
            alias="TF_logic_db_test",
            database_ids=[
                "35617919",
                "35617920",
            ])
        ```

        ## Import

        DMS Enterprise Logic Database can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dms/enterpriseLogicDatabase:EnterpriseLogicDatabase example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alias: Logical Library alias.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] database_ids: Sub-Database ID
        :param pulumi.Input[str] logic_database_id: The ID of the logical Library.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnterpriseLogicDatabaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DMS Enterprise Logic Database resource.

        For information about DMS Enterprise Logic Database and how to use it, see [What is Logic Database](https://www.alibabacloud.com/help/en/dms/developer-reference/api-dms-enterprise-2018-11-01-createlogicdatabase).

        > **NOTE:** Available in v1.195.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.dms.EnterpriseLogicDatabase("default",
            alias="TF_logic_db_test",
            database_ids=[
                "35617919",
                "35617920",
            ])
        ```

        ## Import

        DMS Enterprise Logic Database can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dms/enterpriseLogicDatabase:EnterpriseLogicDatabase example <id>
        ```

        :param str resource_name: The name of the resource.
        :param EnterpriseLogicDatabaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnterpriseLogicDatabaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias: Optional[pulumi.Input[str]] = None,
                 database_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 logic_database_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnterpriseLogicDatabaseArgs.__new__(EnterpriseLogicDatabaseArgs)

            if alias is None and not opts.urn:
                raise TypeError("Missing required property 'alias'")
            __props__.__dict__["alias"] = alias
            if database_ids is None and not opts.urn:
                raise TypeError("Missing required property 'database_ids'")
            __props__.__dict__["database_ids"] = database_ids
            __props__.__dict__["logic_database_id"] = logic_database_id
            __props__.__dict__["db_type"] = None
            __props__.__dict__["env_type"] = None
            __props__.__dict__["logic"] = None
            __props__.__dict__["owner_id_lists"] = None
            __props__.__dict__["owner_name_lists"] = None
            __props__.__dict__["schema_name"] = None
            __props__.__dict__["search_name"] = None
        super(EnterpriseLogicDatabase, __self__).__init__(
            'alicloud:dms/enterpriseLogicDatabase:EnterpriseLogicDatabase',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alias: Optional[pulumi.Input[str]] = None,
            database_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            db_type: Optional[pulumi.Input[str]] = None,
            env_type: Optional[pulumi.Input[str]] = None,
            logic: Optional[pulumi.Input[bool]] = None,
            logic_database_id: Optional[pulumi.Input[str]] = None,
            owner_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            owner_name_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            search_name: Optional[pulumi.Input[str]] = None) -> 'EnterpriseLogicDatabase':
        """
        Get an existing EnterpriseLogicDatabase resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alias: Logical Library alias.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] database_ids: Sub-Database ID
        :param pulumi.Input[str] db_type: Database type.
        :param pulumi.Input[str] env_type: Environment type, return value is as follows:-product: production environment-dev: development environment-pre: Advance Environment-test: test environment-sit:SIT environment-uat:UAT environment-pet: Pressure measurement environment-stag:STAG environment
        :param pulumi.Input[bool] logic: Whether it is a logical Library, the return value is true.
        :param pulumi.Input[str] logic_database_id: The ID of the logical Library.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] owner_id_lists: The user ID list of the logical library Owner.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] owner_name_lists: The nickname list of the logical library Owner.
        :param pulumi.Input[str] schema_name: Logical Library name.
        :param pulumi.Input[str] search_name: Logical library search name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EnterpriseLogicDatabaseState.__new__(_EnterpriseLogicDatabaseState)

        __props__.__dict__["alias"] = alias
        __props__.__dict__["database_ids"] = database_ids
        __props__.__dict__["db_type"] = db_type
        __props__.__dict__["env_type"] = env_type
        __props__.__dict__["logic"] = logic
        __props__.__dict__["logic_database_id"] = logic_database_id
        __props__.__dict__["owner_id_lists"] = owner_id_lists
        __props__.__dict__["owner_name_lists"] = owner_name_lists
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["search_name"] = search_name
        return EnterpriseLogicDatabase(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def alias(self) -> pulumi.Output[str]:
        """
        Logical Library alias.
        """
        return pulumi.get(self, "alias")

    @property
    @pulumi.getter(name="databaseIds")
    def database_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        Sub-Database ID
        """
        return pulumi.get(self, "database_ids")

    @property
    @pulumi.getter(name="dbType")
    def db_type(self) -> pulumi.Output[str]:
        """
        Database type.
        """
        return pulumi.get(self, "db_type")

    @property
    @pulumi.getter(name="envType")
    def env_type(self) -> pulumi.Output[str]:
        """
        Environment type, return value is as follows:-product: production environment-dev: development environment-pre: Advance Environment-test: test environment-sit:SIT environment-uat:UAT environment-pet: Pressure measurement environment-stag:STAG environment
        """
        return pulumi.get(self, "env_type")

    @property
    @pulumi.getter
    def logic(self) -> pulumi.Output[bool]:
        """
        Whether it is a logical Library, the return value is true.
        """
        return pulumi.get(self, "logic")

    @property
    @pulumi.getter(name="logicDatabaseId")
    def logic_database_id(self) -> pulumi.Output[str]:
        """
        The ID of the logical Library.
        """
        return pulumi.get(self, "logic_database_id")

    @property
    @pulumi.getter(name="ownerIdLists")
    def owner_id_lists(self) -> pulumi.Output[Sequence[str]]:
        """
        The user ID list of the logical library Owner.
        """
        return pulumi.get(self, "owner_id_lists")

    @property
    @pulumi.getter(name="ownerNameLists")
    def owner_name_lists(self) -> pulumi.Output[Sequence[str]]:
        """
        The nickname list of the logical library Owner.
        """
        return pulumi.get(self, "owner_name_lists")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[str]:
        """
        Logical Library name.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter(name="searchName")
    def search_name(self) -> pulumi.Output[str]:
        """
        Logical library search name.
        """
        return pulumi.get(self, "search_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerPlansResult',
    'AwaitableGetServerPlansResult',
    'get_server_plans',
    'get_server_plans_output',
]

@pulumi.output_type
class GetServerPlansResult:
    """
    A collection of values returned by getServerPlans.
    """
    def __init__(__self__, bandwidth=None, core=None, disk_size=None, flow=None, id=None, ids=None, memory=None, output_file=None, plans=None, platform=None):
        if bandwidth and not isinstance(bandwidth, int):
            raise TypeError("Expected argument 'bandwidth' to be a int")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if core and not isinstance(core, int):
            raise TypeError("Expected argument 'core' to be a int")
        pulumi.set(__self__, "core", core)
        if disk_size and not isinstance(disk_size, int):
            raise TypeError("Expected argument 'disk_size' to be a int")
        pulumi.set(__self__, "disk_size", disk_size)
        if flow and not isinstance(flow, int):
            raise TypeError("Expected argument 'flow' to be a int")
        pulumi.set(__self__, "flow", flow)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if plans and not isinstance(plans, list):
            raise TypeError("Expected argument 'plans' to be a list")
        pulumi.set(__self__, "plans", plans)
        if platform and not isinstance(platform, str):
            raise TypeError("Expected argument 'platform' to be a str")
        pulumi.set(__self__, "platform", platform)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[int]:
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter
    def core(self) -> Optional[int]:
        return pulumi.get(self, "core")

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[int]:
        return pulumi.get(self, "disk_size")

    @property
    @pulumi.getter
    def flow(self) -> Optional[int]:
        return pulumi.get(self, "flow")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def memory(self) -> Optional[int]:
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def plans(self) -> Sequence['outputs.GetServerPlansPlanResult']:
        return pulumi.get(self, "plans")

    @property
    @pulumi.getter
    def platform(self) -> Optional[str]:
        return pulumi.get(self, "platform")


class AwaitableGetServerPlansResult(GetServerPlansResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerPlansResult(
            bandwidth=self.bandwidth,
            core=self.core,
            disk_size=self.disk_size,
            flow=self.flow,
            id=self.id,
            ids=self.ids,
            memory=self.memory,
            output_file=self.output_file,
            plans=self.plans,
            platform=self.platform)


def get_server_plans(bandwidth: Optional[int] = None,
                     core: Optional[int] = None,
                     disk_size: Optional[int] = None,
                     flow: Optional[int] = None,
                     ids: Optional[Sequence[str]] = None,
                     memory: Optional[int] = None,
                     output_file: Optional[str] = None,
                     platform: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerPlansResult:
    """
    This data source provides the Simple Application Server Plans of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.135.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.simpleapplicationserver.get_server_plans(memory=1,
        bandwidth=3,
        disk_size=40,
        flow=6,
        core=2)
    pulumi.export("simpleApplicationServerPlanId1", ids["plans"][0]["id"])
    ```


    :param int bandwidth: The peak bandwidth. Unit: Mbit/s.
    :param int core: The number of CPU cores.
    :param int disk_size: The size of the enhanced SSD (ESSD). Unit: GB.
    :param int flow: The monthly data transfer quota. Unit: GB.
    :param Sequence[str] ids: A list of Instance Plan IDs.
    :param int memory: The memory size. Unit: GB.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str platform: The platform of Plan supported. Valid values: ["Linux", "Windows"].
    """
    __args__ = dict()
    __args__['bandwidth'] = bandwidth
    __args__['core'] = core
    __args__['diskSize'] = disk_size
    __args__['flow'] = flow
    __args__['ids'] = ids
    __args__['memory'] = memory
    __args__['outputFile'] = output_file
    __args__['platform'] = platform
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:simpleapplicationserver/getServerPlans:getServerPlans', __args__, opts=opts, typ=GetServerPlansResult).value

    return AwaitableGetServerPlansResult(
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        core=pulumi.get(__ret__, 'core'),
        disk_size=pulumi.get(__ret__, 'disk_size'),
        flow=pulumi.get(__ret__, 'flow'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        memory=pulumi.get(__ret__, 'memory'),
        output_file=pulumi.get(__ret__, 'output_file'),
        plans=pulumi.get(__ret__, 'plans'),
        platform=pulumi.get(__ret__, 'platform'))
def get_server_plans_output(bandwidth: Optional[pulumi.Input[Optional[int]]] = None,
                            core: Optional[pulumi.Input[Optional[int]]] = None,
                            disk_size: Optional[pulumi.Input[Optional[int]]] = None,
                            flow: Optional[pulumi.Input[Optional[int]]] = None,
                            ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            memory: Optional[pulumi.Input[Optional[int]]] = None,
                            output_file: Optional[pulumi.Input[Optional[str]]] = None,
                            platform: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetServerPlansResult]:
    """
    This data source provides the Simple Application Server Plans of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.135.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.simpleapplicationserver.get_server_plans(memory=1,
        bandwidth=3,
        disk_size=40,
        flow=6,
        core=2)
    pulumi.export("simpleApplicationServerPlanId1", ids["plans"][0]["id"])
    ```


    :param int bandwidth: The peak bandwidth. Unit: Mbit/s.
    :param int core: The number of CPU cores.
    :param int disk_size: The size of the enhanced SSD (ESSD). Unit: GB.
    :param int flow: The monthly data transfer quota. Unit: GB.
    :param Sequence[str] ids: A list of Instance Plan IDs.
    :param int memory: The memory size. Unit: GB.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str platform: The platform of Plan supported. Valid values: ["Linux", "Windows"].
    """
    __args__ = dict()
    __args__['bandwidth'] = bandwidth
    __args__['core'] = core
    __args__['diskSize'] = disk_size
    __args__['flow'] = flow
    __args__['ids'] = ids
    __args__['memory'] = memory
    __args__['outputFile'] = output_file
    __args__['platform'] = platform
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:simpleapplicationserver/getServerPlans:getServerPlans', __args__, opts=opts, typ=GetServerPlansResult)
    return __ret__.apply(lambda __response__: GetServerPlansResult(
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        core=pulumi.get(__response__, 'core'),
        disk_size=pulumi.get(__response__, 'disk_size'),
        flow=pulumi.get(__response__, 'flow'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        memory=pulumi.get(__response__, 'memory'),
        output_file=pulumi.get(__response__, 'output_file'),
        plans=pulumi.get(__response__, 'plans'),
        platform=pulumi.get(__response__, 'platform')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TransitRouterVpnAttachmentArgs', 'TransitRouterVpnAttachment']

@pulumi.input_type
class TransitRouterVpnAttachmentArgs:
    def __init__(__self__, *,
                 transit_router_id: pulumi.Input[str],
                 vpn_id: pulumi.Input[str],
                 zones: pulumi.Input[Sequence[pulumi.Input['TransitRouterVpnAttachmentZoneArgs']]],
                 auto_publish_route_enabled: Optional[pulumi.Input[bool]] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 transit_router_attachment_description: Optional[pulumi.Input[str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[str]] = None,
                 vpn_owner_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a TransitRouterVpnAttachment resource.
        :param pulumi.Input[str] transit_router_id: The ID of the forwarding router instance.
        :param pulumi.Input[str] vpn_id: The id of the vpn.
        :param pulumi.Input[Sequence[pulumi.Input['TransitRouterVpnAttachmentZoneArgs']]] zones: The list of zone mapping. See `zone` below.
        :param pulumi.Input[bool] auto_publish_route_enabled: Whether to allow the forwarding router instance to automatically publish routing entries to IPsec connections.
        :param pulumi.Input[str] cen_id: The id of the cen.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] transit_router_attachment_description: The description of the VPN connection. The description can contain `2` to `256` characters. The description must start with English letters, but cannot start with `http://` or `https://`.
        :param pulumi.Input[str] transit_router_attachment_name: The name of the VPN connection. The name must be `2` to `128` characters in length, and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
        :param pulumi.Input[str] vpn_owner_id: The owner id of vpn. **NOTE:** You must set `vpn_owner_id`, if you want to connect the transit router to an IPsec-VPN connection that belongs to another Alibaba Cloud account.
        """
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        pulumi.set(__self__, "vpn_id", vpn_id)
        pulumi.set(__self__, "zones", zones)
        if auto_publish_route_enabled is not None:
            pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_description is not None:
            pulumi.set(__self__, "transit_router_attachment_description", transit_router_attachment_description)
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if vpn_owner_id is not None:
            pulumi.set(__self__, "vpn_owner_id", vpn_owner_id)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Input[str]:
        """
        The ID of the forwarding router instance.
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="vpnId")
    def vpn_id(self) -> pulumi.Input[str]:
        """
        The id of the vpn.
        """
        return pulumi.get(self, "vpn_id")

    @vpn_id.setter
    def vpn_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpn_id", value)

    @property
    @pulumi.getter
    def zones(self) -> pulumi.Input[Sequence[pulumi.Input['TransitRouterVpnAttachmentZoneArgs']]]:
        """
        The list of zone mapping. See `zone` below.
        """
        return pulumi.get(self, "zones")

    @zones.setter
    def zones(self, value: pulumi.Input[Sequence[pulumi.Input['TransitRouterVpnAttachmentZoneArgs']]]):
        pulumi.set(self, "zones", value)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to allow the forwarding router instance to automatically publish routing entries to IPsec connections.
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @auto_publish_route_enabled.setter
    def auto_publish_route_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_publish_route_enabled", value)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the cen.
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentDescription")
    def transit_router_attachment_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the VPN connection. The description can contain `2` to `256` characters. The description must start with English letters, but cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "transit_router_attachment_description")

    @transit_router_attachment_description.setter
    def transit_router_attachment_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "transit_router_attachment_description", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the VPN connection. The name must be `2` to `128` characters in length, and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "transit_router_attachment_name", value)

    @property
    @pulumi.getter(name="vpnOwnerId")
    def vpn_owner_id(self) -> Optional[pulumi.Input[str]]:
        """
        The owner id of vpn. **NOTE:** You must set `vpn_owner_id`, if you want to connect the transit router to an IPsec-VPN connection that belongs to another Alibaba Cloud account.
        """
        return pulumi.get(self, "vpn_owner_id")

    @vpn_owner_id.setter
    def vpn_owner_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpn_owner_id", value)


@pulumi.input_type
class _TransitRouterVpnAttachmentState:
    def __init__(__self__, *,
                 auto_publish_route_enabled: Optional[pulumi.Input[bool]] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 transit_router_attachment_description: Optional[pulumi.Input[str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[str]] = None,
                 transit_router_id: Optional[pulumi.Input[str]] = None,
                 vpn_id: Optional[pulumi.Input[str]] = None,
                 vpn_owner_id: Optional[pulumi.Input[str]] = None,
                 zones: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterVpnAttachmentZoneArgs']]]] = None):
        """
        Input properties used for looking up and filtering TransitRouterVpnAttachment resources.
        :param pulumi.Input[bool] auto_publish_route_enabled: Whether to allow the forwarding router instance to automatically publish routing entries to IPsec connections.
        :param pulumi.Input[str] cen_id: The id of the cen.
        :param pulumi.Input[str] status: The associating status of the network.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] transit_router_attachment_description: The description of the VPN connection. The description can contain `2` to `256` characters. The description must start with English letters, but cannot start with `http://` or `https://`.
        :param pulumi.Input[str] transit_router_attachment_name: The name of the VPN connection. The name must be `2` to `128` characters in length, and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
        :param pulumi.Input[str] transit_router_id: The ID of the forwarding router instance.
        :param pulumi.Input[str] vpn_id: The id of the vpn.
        :param pulumi.Input[str] vpn_owner_id: The owner id of vpn. **NOTE:** You must set `vpn_owner_id`, if you want to connect the transit router to an IPsec-VPN connection that belongs to another Alibaba Cloud account.
        :param pulumi.Input[Sequence[pulumi.Input['TransitRouterVpnAttachmentZoneArgs']]] zones: The list of zone mapping. See `zone` below.
        """
        if auto_publish_route_enabled is not None:
            pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_description is not None:
            pulumi.set(__self__, "transit_router_attachment_description", transit_router_attachment_description)
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)
        if vpn_id is not None:
            pulumi.set(__self__, "vpn_id", vpn_id)
        if vpn_owner_id is not None:
            pulumi.set(__self__, "vpn_owner_id", vpn_owner_id)
        if zones is not None:
            pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to allow the forwarding router instance to automatically publish routing entries to IPsec connections.
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @auto_publish_route_enabled.setter
    def auto_publish_route_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_publish_route_enabled", value)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the cen.
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The associating status of the network.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentDescription")
    def transit_router_attachment_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the VPN connection. The description can contain `2` to `256` characters. The description must start with English letters, but cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "transit_router_attachment_description")

    @transit_router_attachment_description.setter
    def transit_router_attachment_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "transit_router_attachment_description", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the VPN connection. The name must be `2` to `128` characters in length, and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "transit_router_attachment_name", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the forwarding router instance.
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="vpnId")
    def vpn_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the vpn.
        """
        return pulumi.get(self, "vpn_id")

    @vpn_id.setter
    def vpn_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpn_id", value)

    @property
    @pulumi.getter(name="vpnOwnerId")
    def vpn_owner_id(self) -> Optional[pulumi.Input[str]]:
        """
        The owner id of vpn. **NOTE:** You must set `vpn_owner_id`, if you want to connect the transit router to an IPsec-VPN connection that belongs to another Alibaba Cloud account.
        """
        return pulumi.get(self, "vpn_owner_id")

    @vpn_owner_id.setter
    def vpn_owner_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpn_owner_id", value)

    @property
    @pulumi.getter
    def zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterVpnAttachmentZoneArgs']]]]:
        """
        The list of zone mapping. See `zone` below.
        """
        return pulumi.get(self, "zones")

    @zones.setter
    def zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterVpnAttachmentZoneArgs']]]]):
        pulumi.set(self, "zones", value)


class TransitRouterVpnAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_publish_route_enabled: Optional[pulumi.Input[bool]] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 transit_router_attachment_description: Optional[pulumi.Input[str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[str]] = None,
                 transit_router_id: Optional[pulumi.Input[str]] = None,
                 vpn_id: Optional[pulumi.Input[str]] = None,
                 vpn_owner_id: Optional[pulumi.Input[str]] = None,
                 zones: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterVpnAttachmentZoneArgs', 'TransitRouterVpnAttachmentZoneArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a Cloud Enterprise Network (CEN) Transit Router Vpn Attachment resource.

        For information about Cloud Enterprise Network (CEN) Transit Router Vpn Attachment and how to use it, see [What is Transit Router Vpn Attachment](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-createtransitroutervpnattachment).

        > **NOTE:** Available since v1.183.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        default = alicloud.cen.get_transit_router_available_resources()
        example = alicloud.cen.Instance("example", cen_instance_name=name)
        example_transit_router = alicloud.cen.TransitRouter("example",
            cen_id=example.id,
            transit_router_description=name,
            transit_router_name=name)
        example_customer_gateway = alicloud.vpn.CustomerGateway("example",
            customer_gateway_name=name,
            ip_address="42.104.22.210",
            asn="45014",
            description=name)
        example_gateway_vpn_attachment = alicloud.vpn.GatewayVpnAttachment("example",
            customer_gateway_id=example_customer_gateway.id,
            network_type="public",
            local_subnet="0.0.0.0/0",
            remote_subnet="0.0.0.0/0",
            effect_immediately=False,
            ike_config={
                "ike_auth_alg": "md5",
                "ike_enc_alg": "des",
                "ike_version": "ikev2",
                "ike_mode": "main",
                "ike_lifetime": 86400,
                "psk": "tf-testvpn2",
                "ike_pfs": "group1",
                "remote_id": "testbob2",
                "local_id": "testalice2",
            },
            ipsec_config={
                "ipsec_pfs": "group5",
                "ipsec_enc_alg": "des",
                "ipsec_auth_alg": "md5",
                "ipsec_lifetime": 86400,
            },
            bgp_config={
                "enable": True,
                "local_asn": 45014,
                "tunnel_cidr": "169.254.11.0/30",
                "local_bgp_ip": "169.254.11.1",
            },
            health_check_config={
                "enable": True,
                "sip": "192.168.1.1",
                "dip": "10.0.0.1",
                "interval": 10,
                "retry": 10,
                "policy": "revoke_route",
            },
            enable_dpd=True,
            enable_nat_traversal=True,
            vpn_attachment_name=name)
        example_transit_router_cidr = alicloud.cen.TransitRouterCidr("example",
            transit_router_id=example_transit_router.transit_router_id,
            cidr="192.168.0.0/16",
            transit_router_cidr_name=name,
            description=name,
            publish_cidr_route=True)
        example_transit_router_vpn_attachment = alicloud.cen.TransitRouterVpnAttachment("example",
            auto_publish_route_enabled=False,
            transit_router_attachment_description=name,
            transit_router_attachment_name=name,
            cen_id=example_transit_router.cen_id,
            transit_router_id=example_transit_router_cidr.transit_router_id,
            vpn_id=example_gateway_vpn_attachment.id,
            zones=[{
                "zone_id": default.resources[0].master_zones[0],
            }])
        ```

        ## Import

        Cloud Enterprise Network (CEN) Transit Router Vpn Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/transitRouterVpnAttachment:TransitRouterVpnAttachment example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_publish_route_enabled: Whether to allow the forwarding router instance to automatically publish routing entries to IPsec connections.
        :param pulumi.Input[str] cen_id: The id of the cen.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] transit_router_attachment_description: The description of the VPN connection. The description can contain `2` to `256` characters. The description must start with English letters, but cannot start with `http://` or `https://`.
        :param pulumi.Input[str] transit_router_attachment_name: The name of the VPN connection. The name must be `2` to `128` characters in length, and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
        :param pulumi.Input[str] transit_router_id: The ID of the forwarding router instance.
        :param pulumi.Input[str] vpn_id: The id of the vpn.
        :param pulumi.Input[str] vpn_owner_id: The owner id of vpn. **NOTE:** You must set `vpn_owner_id`, if you want to connect the transit router to an IPsec-VPN connection that belongs to another Alibaba Cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterVpnAttachmentZoneArgs', 'TransitRouterVpnAttachmentZoneArgsDict']]]] zones: The list of zone mapping. See `zone` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TransitRouterVpnAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Enterprise Network (CEN) Transit Router Vpn Attachment resource.

        For information about Cloud Enterprise Network (CEN) Transit Router Vpn Attachment and how to use it, see [What is Transit Router Vpn Attachment](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-createtransitroutervpnattachment).

        > **NOTE:** Available since v1.183.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        default = alicloud.cen.get_transit_router_available_resources()
        example = alicloud.cen.Instance("example", cen_instance_name=name)
        example_transit_router = alicloud.cen.TransitRouter("example",
            cen_id=example.id,
            transit_router_description=name,
            transit_router_name=name)
        example_customer_gateway = alicloud.vpn.CustomerGateway("example",
            customer_gateway_name=name,
            ip_address="42.104.22.210",
            asn="45014",
            description=name)
        example_gateway_vpn_attachment = alicloud.vpn.GatewayVpnAttachment("example",
            customer_gateway_id=example_customer_gateway.id,
            network_type="public",
            local_subnet="0.0.0.0/0",
            remote_subnet="0.0.0.0/0",
            effect_immediately=False,
            ike_config={
                "ike_auth_alg": "md5",
                "ike_enc_alg": "des",
                "ike_version": "ikev2",
                "ike_mode": "main",
                "ike_lifetime": 86400,
                "psk": "tf-testvpn2",
                "ike_pfs": "group1",
                "remote_id": "testbob2",
                "local_id": "testalice2",
            },
            ipsec_config={
                "ipsec_pfs": "group5",
                "ipsec_enc_alg": "des",
                "ipsec_auth_alg": "md5",
                "ipsec_lifetime": 86400,
            },
            bgp_config={
                "enable": True,
                "local_asn": 45014,
                "tunnel_cidr": "169.254.11.0/30",
                "local_bgp_ip": "169.254.11.1",
            },
            health_check_config={
                "enable": True,
                "sip": "192.168.1.1",
                "dip": "10.0.0.1",
                "interval": 10,
                "retry": 10,
                "policy": "revoke_route",
            },
            enable_dpd=True,
            enable_nat_traversal=True,
            vpn_attachment_name=name)
        example_transit_router_cidr = alicloud.cen.TransitRouterCidr("example",
            transit_router_id=example_transit_router.transit_router_id,
            cidr="192.168.0.0/16",
            transit_router_cidr_name=name,
            description=name,
            publish_cidr_route=True)
        example_transit_router_vpn_attachment = alicloud.cen.TransitRouterVpnAttachment("example",
            auto_publish_route_enabled=False,
            transit_router_attachment_description=name,
            transit_router_attachment_name=name,
            cen_id=example_transit_router.cen_id,
            transit_router_id=example_transit_router_cidr.transit_router_id,
            vpn_id=example_gateway_vpn_attachment.id,
            zones=[{
                "zone_id": default.resources[0].master_zones[0],
            }])
        ```

        ## Import

        Cloud Enterprise Network (CEN) Transit Router Vpn Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/transitRouterVpnAttachment:TransitRouterVpnAttachment example <id>
        ```

        :param str resource_name: The name of the resource.
        :param TransitRouterVpnAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TransitRouterVpnAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_publish_route_enabled: Optional[pulumi.Input[bool]] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 transit_router_attachment_description: Optional[pulumi.Input[str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[str]] = None,
                 transit_router_id: Optional[pulumi.Input[str]] = None,
                 vpn_id: Optional[pulumi.Input[str]] = None,
                 vpn_owner_id: Optional[pulumi.Input[str]] = None,
                 zones: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterVpnAttachmentZoneArgs', 'TransitRouterVpnAttachmentZoneArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TransitRouterVpnAttachmentArgs.__new__(TransitRouterVpnAttachmentArgs)

            __props__.__dict__["auto_publish_route_enabled"] = auto_publish_route_enabled
            __props__.__dict__["cen_id"] = cen_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["transit_router_attachment_description"] = transit_router_attachment_description
            __props__.__dict__["transit_router_attachment_name"] = transit_router_attachment_name
            if transit_router_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_id'")
            __props__.__dict__["transit_router_id"] = transit_router_id
            if vpn_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpn_id'")
            __props__.__dict__["vpn_id"] = vpn_id
            __props__.__dict__["vpn_owner_id"] = vpn_owner_id
            if zones is None and not opts.urn:
                raise TypeError("Missing required property 'zones'")
            __props__.__dict__["zones"] = zones
            __props__.__dict__["status"] = None
        super(TransitRouterVpnAttachment, __self__).__init__(
            'alicloud:cen/transitRouterVpnAttachment:TransitRouterVpnAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_publish_route_enabled: Optional[pulumi.Input[bool]] = None,
            cen_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            transit_router_attachment_description: Optional[pulumi.Input[str]] = None,
            transit_router_attachment_name: Optional[pulumi.Input[str]] = None,
            transit_router_id: Optional[pulumi.Input[str]] = None,
            vpn_id: Optional[pulumi.Input[str]] = None,
            vpn_owner_id: Optional[pulumi.Input[str]] = None,
            zones: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterVpnAttachmentZoneArgs', 'TransitRouterVpnAttachmentZoneArgsDict']]]]] = None) -> 'TransitRouterVpnAttachment':
        """
        Get an existing TransitRouterVpnAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_publish_route_enabled: Whether to allow the forwarding router instance to automatically publish routing entries to IPsec connections.
        :param pulumi.Input[str] cen_id: The id of the cen.
        :param pulumi.Input[str] status: The associating status of the network.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] transit_router_attachment_description: The description of the VPN connection. The description can contain `2` to `256` characters. The description must start with English letters, but cannot start with `http://` or `https://`.
        :param pulumi.Input[str] transit_router_attachment_name: The name of the VPN connection. The name must be `2` to `128` characters in length, and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
        :param pulumi.Input[str] transit_router_id: The ID of the forwarding router instance.
        :param pulumi.Input[str] vpn_id: The id of the vpn.
        :param pulumi.Input[str] vpn_owner_id: The owner id of vpn. **NOTE:** You must set `vpn_owner_id`, if you want to connect the transit router to an IPsec-VPN connection that belongs to another Alibaba Cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterVpnAttachmentZoneArgs', 'TransitRouterVpnAttachmentZoneArgsDict']]]] zones: The list of zone mapping. See `zone` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TransitRouterVpnAttachmentState.__new__(_TransitRouterVpnAttachmentState)

        __props__.__dict__["auto_publish_route_enabled"] = auto_publish_route_enabled
        __props__.__dict__["cen_id"] = cen_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["transit_router_attachment_description"] = transit_router_attachment_description
        __props__.__dict__["transit_router_attachment_name"] = transit_router_attachment_name
        __props__.__dict__["transit_router_id"] = transit_router_id
        __props__.__dict__["vpn_id"] = vpn_id
        __props__.__dict__["vpn_owner_id"] = vpn_owner_id
        __props__.__dict__["zones"] = zones
        return TransitRouterVpnAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> pulumi.Output[bool]:
        """
        Whether to allow the forwarding router instance to automatically publish routing entries to IPsec connections.
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Output[Optional[str]]:
        """
        The id of the cen.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The associating status of the network.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterAttachmentDescription")
    def transit_router_attachment_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the VPN connection. The description can contain `2` to `256` characters. The description must start with English letters, but cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "transit_router_attachment_description")

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the VPN connection. The name must be `2` to `128` characters in length, and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[str]:
        """
        The ID of the forwarding router instance.
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="vpnId")
    def vpn_id(self) -> pulumi.Output[str]:
        """
        The id of the vpn.
        """
        return pulumi.get(self, "vpn_id")

    @property
    @pulumi.getter(name="vpnOwnerId")
    def vpn_owner_id(self) -> pulumi.Output[str]:
        """
        The owner id of vpn. **NOTE:** You must set `vpn_owner_id`, if you want to connect the transit router to an IPsec-VPN connection that belongs to another Alibaba Cloud account.
        """
        return pulumi.get(self, "vpn_owner_id")

    @property
    @pulumi.getter
    def zones(self) -> pulumi.Output[Sequence['outputs.TransitRouterVpnAttachmentZone']]:
        """
        The list of zone mapping. See `zone` below.
        """
        return pulumi.get(self, "zones")

